@@ -36,6 +36,56 @@
 
 PyTypeObject igraphmodule_EdgeType;
 
+/**
+ * \ingroup python_interface_edge
+ * \brief Checks whether the given Python object is an edge
+ */
+int igraphmodule_Edge_Check(PyObject* obj) {
+  if (!obj)
+    return 0;
+  
+  return PyObject_IsInstance(obj, (PyObject*)(&igraphmodule_EdgeType));
+}
+
+/**
+ * \ingroup python_interface_edge
+ * \brief Checks whether the index in the given edge object is a valid one.
+ * \return nonzero if the edge object is valid. Raises an appropriate Python
+ *   exception and returns zero if the edge object is invalid.
+ */
+int igraphmodule_Edge_Validate(PyObject* obj) {
+  igraph_integer_t n;
+  igraphmodule_EdgeObject *self;
+  igraphmodule_GraphObject *graph;
+
+  if (!igraphmodule_Edge_Check(obj)) {
+    PyErr_SetString(PyExc_TypeError, "object is not an Edge");
+    return 0;
+  }
+
+  self = (igraphmodule_EdgeObject*)obj;
+  graph = self->gref;
+
+  if (graph == 0) {
+    PyErr_SetString(PyExc_ValueError, "Edge object refers to a null graph");
+    return 0;
+  }
+
+  if (self->idx < 0) {
+    PyErr_SetString(PyExc_ValueError, "Edge object refers to a negative edge index");
+    return 0;
+  }
+
+  n = igraph_ecount(&graph->g);
+
+  if (self->idx >= n) {
+    PyErr_SetString(PyExc_ValueError, "Edge object refers to a nonexistent edge");
+    return 0;
+  }
+
+  return 1;
+}
+
 /**
  * \ingroup python_interface_edge
  * \brief Allocates a new Python edge object
@@ -56,6 +106,7 @@ PyObject* igraphmodule_Edge_New(igraphmodule_GraphObject *gref, igraph_integer_t
     Py_INCREF(gref);
     self->gref=gref;
     self->idx=idx;
+    self->hash=-1;
   }
   return (PyObject*)self;
 }
@@ -123,6 +174,82 @@ PyObject* igraphmodule_Edge_repr(igraphmodule_EdgeObject *self) {
   return s;
 }
 
+/** \ingroup python_interface_edge
+ * \brief Returns the hash code of the edge
+ */
+Py_hash_t igraphmodule_Edge_hash(igraphmodule_EdgeObject* self) {
+  Py_hash_t hash_graph;
+  Py_hash_t hash_index;
+  Py_hash_t result;
+  PyObject* index_o;
+
+  if (self->hash != -1)
+    return self->hash;
+
+  index_o = PyInt_FromLong((long int)self->idx);
+  if (index_o == 0)
+    return -1;
+
+  hash_index = PyObject_Hash(index_o);
+  Py_DECREF(index_o);
+
+  if (hash_index == -1)
+    return -1;
+
+  hash_graph = PyObject_Hash((PyObject*)self->gref);
+  if (hash_graph == -1)
+    return -1;
+
+  result = hash_graph ^ hash_index;
+  if (result == -1)
+    result = 590923713U;
+
+  self->hash = result;
+
+  return result;
+}
+
+/** \ingroup python_interface_edge
+ * \brief Rich comparison of an edge with another
+ */
+PyObject* igraphmodule_Edge_richcompare(igraphmodule_EdgeObject *a,
+    PyObject *b, int op) {
+
+  igraphmodule_EdgeObject* self = a;
+  igraphmodule_EdgeObject* other;
+
+  if (!igraphmodule_Edge_Check(b))
+    Py_RETURN_NOTIMPLEMENTED;
+
+  other = (igraphmodule_EdgeObject*)b;
+
+  if (self->gref != other->gref)
+    Py_RETURN_FALSE;
+
+  switch (op) {
+    case Py_EQ:
+      Py_RETURN(self->idx == other->idx);
+
+    case Py_NE:
+      Py_RETURN(self->idx != other->idx);
+
+    case Py_LE:
+      Py_RETURN(self->idx <= other->idx);
+
+    case Py_LT:
+      Py_RETURN(self->idx <  other->idx);
+
+    case Py_GE:
+      Py_RETURN(self->idx >= other->idx);
+
+    case Py_GT:
+      Py_RETURN(self->idx >  other->idx);
+
+    default:
+      Py_RETURN_NOTIMPLEMENTED;
+  }
+}
+
 /** \ingroup python_interface_edge
  * \brief Returns the number of edge attributes
  */
@@ -150,6 +277,9 @@ PyObject* igraphmodule_Edge_attributes(igraphmodule_EdgeObject* self) {
   PyObject *names, *dict;
   long int i, n;
 
+  if (!igraphmodule_Edge_Validate((PyObject*)self))
+    return 0;
+
   dict=PyDict_New();
   if (!dict)
     return NULL;
@@ -176,6 +306,8 @@ PyObject* igraphmodule_Edge_attributes(igraphmodule_EdgeObject* self) {
     }
   }
 
+  Py_DECREF(names);
+
   return dict;
 }
 
@@ -202,6 +334,12 @@ PyObject* igraphmodule_Edge_get_attribute(igraphmodule_EdgeObject* self,
   igraphmodule_GraphObject *o = self->gref;
   PyObject* result;
 
+  if (!igraphmodule_Edge_Validate((PyObject*)self))
+    return 0;
+
+  if (!igraphmodule_attribute_name_check(s))
+    return 0;
+
   result=PyDict_GetItem(((PyObject**)o->g.attr)[2], s);
   if (result) {
     /* result is a list, so get the element with index self->idx */
@@ -232,7 +370,11 @@ int igraphmodule_Edge_set_attribute(igraphmodule_EdgeObject* self, PyObject* k,
   PyObject* result;
   int r;
   
-  if (o==0) return -1;
+  if (!igraphmodule_Edge_Validate((PyObject*)self))
+    return -1;
+
+  if (!igraphmodule_attribute_name_check(k))
+    return -1;
 
   if (v==NULL)
     // we are deleting attribute
@@ -295,7 +437,10 @@ int igraphmodule_Edge_set_attribute(igraphmodule_EdgeObject* self, PyObject* k,
 PyObject* igraphmodule_Edge_get_from(igraphmodule_EdgeObject* self, void* closure) {
   igraphmodule_GraphObject *o = self->gref;
   igraph_integer_t from, to;
-  
+
+  if (!igraphmodule_Edge_Validate((PyObject*)self))
+    return NULL;
+
   if (igraph_edge(&o->g, self->idx, &from, &to)) {
     igraphmodule_handle_igraph_error(); return NULL;
   }
@@ -310,6 +455,9 @@ PyObject* igraphmodule_Edge_get_to(igraphmodule_EdgeObject* self, void* closure)
   igraphmodule_GraphObject *o = self->gref;
   igraph_integer_t from, to;
   
+  if (!igraphmodule_Edge_Validate((PyObject*)self))
+    return NULL;
+
   if (igraph_edge(&o->g, self->idx, &from, &to)) {
     igraphmodule_handle_igraph_error(); return NULL;
   }
@@ -348,12 +496,23 @@ PyObject* igraphmodule_Edge_get_tuple(igraphmodule_EdgeObject* self, void* closu
   igraphmodule_GraphObject *o = self->gref;
   igraph_integer_t from, to;
   
+  if (!igraphmodule_Edge_Validate((PyObject*)self))
+    return NULL;
+
   if (igraph_edge(&o->g, self->idx, &from, &to)) {
     igraphmodule_handle_igraph_error(); return NULL;
   }
   return Py_BuildValue("(ii)", (long)from, (long)to);
 }
 
+/** \ingroup python_interface_edge
+ * Returns the graph where the edge belongs
+ */
+PyObject* igraphmodule_Edge_get_graph(igraphmodule_EdgeObject* self, void* closure) {
+  Py_INCREF(self->gref);
+  return (PyObject*)self->gref;
+}
+
 #define GRAPH_PROXY_METHOD(FUNC, METHODNAME) \
     PyObject* igraphmodule_Edge_##FUNC(igraphmodule_EdgeObject* self, PyObject* args, PyObject* kwds) { \
       PyObject *new_args, *item, *result;                     \
@@ -449,6 +608,9 @@ PyGetSetDef igraphmodule_Edge_getseters[] = {
   {"index", (getter)igraphmodule_Edge_get_index, NULL,
       "Index of this edge", NULL,
   },
+  {"graph", (getter)igraphmodule_Edge_get_graph, NULL,
+    "The graph the edge belongs to", NULL,
+  },
   {NULL}
 };
 
@@ -485,7 +647,7 @@ PyTypeObject igraphmodule_EdgeType =
   0,                                          // tp_as_number
   0,                                          // tp_as_sequence
   &igraphmodule_Edge_as_mapping,              // tp_as_mapping
-  0,                                          // tp_hash
+  (hashfunc)igraphmodule_Edge_hash,           /* tp_hash */
   0,                                          // tp_call
   0,                                          // tp_str
   0,                                          // tp_getattro
@@ -503,7 +665,7 @@ PyTypeObject igraphmodule_EdgeType =
   "  2\n", // tp_doc
   0,                                          // tp_traverse
   0,                                          // tp_clear
-  0,                                          // tp_richcompare
+  (richcmpfunc)igraphmodule_Edge_richcompare, /* tp_richcompare */
   0,                                          // tp_weaklistoffset
   0,                                          // tp_iter
   0,                                          // tp_iternext
