@@ -1,8 +1,7 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Tamas Nepusz <ntamas@gmail.com>
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,6 +24,7 @@
 #define PYTHON_ERROR_H
 
 #include <Python.h>
+#include <igraph_error.h>
 
 /** \defgroup python_interface_errors Error handling
  * \ingroup python_interface */
@@ -36,4 +36,13 @@ void igraphmodule_igraph_error_hook(const char *reason, const char *file,
 				    int line, int igraph_errno);
 
 extern PyObject* igraphmodule_InternalError;
+
+#define IGRAPH_PYCHECK(a) do { \
+	int igraph_i_pyret=(a); \
+	if (IGRAPH_UNLIKELY(igraph_i_pyret != 0)) {\
+		igraphmodule_handle_igraph_error();  \
+		IGRAPH_FINALLY_FREE();               \
+		return 0;                            \
+	} } while (0)
+
 #endif
